###########################################################################################################
#
#  dropIt
#  
#  @author simon jokuschies
#  @version 3.0
#  @contact info@leafpictures.de
#  @website www.leafpictures.de
#  @plugin: www.leafpictures.de/dropIt  
#
#  description:
#  intuitive deleting nodes: delete selected nodes
#  hold cmd/ctrl and drag selected nodes to the bottom of the screen to delete them - like in flame
#
#  installation
#
#  put dropIt folder in nuke home directory
#  in init.py add this line (without "#"):
#
#  nuke.pluginAddPath("dropIt")
#
##########################################################################################################

#  delete selected nodes if mousepositionY > (screenHeight - dropTollerance)
#  meaning the bigger the dropTollerance the earlier the selected nodes
#  get deleted if the mouse goes to the bottom of the screen
#  usually no need to change it. But if you like you can start the
#  deleting process earlier.
global dropTollerance
dropTollerance = 2

# no need to change anything from here. Edit only if you exactly know what you're doing

from PySide.QtGui import *
from PySide.QtCore import *
import sys
import nuke
import nukescripts

# get nuke main app
try:
    app = QApplication(sys.argv)
except:
    app = QCoreApplication.instance()


def initDropIt():
    """
    initDropIt
    get screen resolution and add knobChanged callback
    @return: None
    """

    global max_h

    screen_height = app.desktop().screenGeometry().height()
    max_h = screen_height-dropTollerance
    nuke.addKnobChanged(dropIt)


def dropIt():
    """
    dropIt when holding cmd/ctrl and dragging node to bottom of screen
    check for screen position
    if mouse.y > screenheight-tollerance then delete selected nodes
    :return: None
    """

    y = QCursor.pos().y()

    modifiers = app.keyboardModifiers()
    if modifiers == Qt.ControlModifier:
        if y > max_h:
            delNodes()


def delNodes():
    """
    copy selected nodes to clipboard and delete selected nodes
    this needs to be a workarounf because deleting the nodes inside the script seems to be undoable for some reason
    so we need some workaround to undo a mistakenly deletion of some nodes. This is solved by copying the nodes
    to the clipboard before deleting them. So if you like to undo the deletion simply press ctrl+v or cmd+v
    to paste the deleted nodes back into your nodegraph.
    :return: None
    """

    try:
        nuke.nodeCopy(nukescripts.cut_paste_file())
        for node in nuke.selectedNodes():
            nuke.delete(node)
    except Exception, e:
        pass
